@@ -862,12 +862,12 @@ class MainWindow(QMainWindow): # Class for main application
 
 	def buttonVisibility(self): # Button visibility, currently only sec2mod & sec2mod2 for canon
 		# print "Setting button visibility..."
-		if CURRENT_REMOTETYPE != "CANON-RC1/RC5" or CURRENT_REMOTETYPE != "Minolta_RC3":
-			self.sec2mod.hide()
-			self.sec2mod2.hide()
-		else:
+		if CURRENT_REMOTETYPE == "CANON-RC1/RC5" or CURRENT_REMOTETYPE == "Minolta_RC3":
 			self.sec2mod.show()
 			self.sec2mod2.show()
+		else:
+			self.sec2mod.hide()
+			self.sec2mod2.hide()
 
 	def tabVisibility(self):
 		# print "Setting tab visibility..."
@@ -1168,7 +1168,7 @@ class MiscFunctions:
 		file = QFile(fileName)
 		
 		if not file.open(QFile.ReadOnly | QFile.Text):
-			# print "Problems while loading file."
+			print "Problems while loading file."
 		
 		data = QTextStream(file)
 		text = data.readAll()
